@@ -4,9 +4,9 @@ from .headers import appjson
 from .statuses import ParcelCarrierSize, ParcelLockerSize, ParcelDeliveryType, ParcelShipmentType, \
     ParcelAdditionalInsurance, ParcelType, ParcelOwnership, CompartmentExpectedStatus, CompartmentActualStatus, \
     ParcelServiceName, ParcelStatus
-from .exceptions import UnidentifiedParcelError, ParcelTypeError, NotAuthenticatedError, ReAuthenticationError, \
-    PhoneNumberError, SmsCodeConfirmationError, RefreshTokenException, UnidentifiedAPIError, UserLocationError, \
-    UnidentifiedError
+from .exceptions import NoParcelError, UnidentifiedParcelError, ParcelTypeError, NotAuthenticatedError, ReAuthenticationError, \
+    PhoneNumberError, SmsCodeError, RefreshTokenError, UnidentifiedAPIError, UserLocationError, \
+    UnidentifiedError, NotFoundError, UnauthorizedError, SingleParamError
 from .endpoints import login, send_sms_code, confirm_sms_code, refresh_token, parcels, parcel, collect, \
     compartment_open, compartment_status, terminate_collect_session, friends, shared, sent, returns, parcel_prices, \
     tickets, logout
